@@ -12,14 +12,20 @@ import os
 
 remote_actions = {}
 registered_apis = []
+registered_endpoints = []
 ACTIONS_SPEC_LOC = "/jaseci_actions_spec/"
 JS_ACTION_PREAMBLE = "js_action_"
+JS_ENDPOINT_PREAMBLE = "js_endpoint_"
 
 
 def mark_as_remote(api):
     registered_apis.append(api)
 
 
+def mark_as_endpoint(endpoint):
+    registered_endpoints.append(endpoint)
+
+
 def serv_actions():
     """Returns fastAPI app interface for actions"""
     app = FastAPI(
@@ -36,7 +42,9 @@ def serv_actions():
         return remote_actions
 
     for i in registered_apis:
-        gen_api_service(app, i[0], i[1], i[2], i[3])
+        gen_api_service(app, *i)
+    for i in registered_endpoints:
+        gen_endpoint(app, *i)
     return app
 
 
@@ -84,5 +92,13 @@ def gen_api_service(app, func, act_group, aliases, caller_globals):
     caller_globals[f"{JS_ACTION_PREAMBLE}{func.__name__}"] = new_func
 
 
+def gen_endpoint(app, func, endpoint, mount, caller_globals):
+    """Helper for jaseci_action decorator"""
+    # Create duplicate funtion for api endpoint and inject in call site globals
+    if mount is not None:
+        app.mount(*mount)
+    caller_globals[f"{JS_ENDPOINT_PREAMBLE}{func.__name__}"] = app.get(endpoint)(func)
+
+
 def launch_server(port=80, host="0.0.0.0"):
     uvicorn.run(serv_actions(), port=port, host=host)
