@@ -339,18 +339,6 @@ class Node(Element, Anchored):
         """Remove node from higher dimension node"""
         node_obj.leave_membership_of(self)
 
-    def set_context(self, ctx, arch=None):
-        """Assign values to context fields of node, arch is node architype"""
-        if arch is None:
-            arch = self
-        for i in ctx.keys():
-            if i not in arch.context.keys():
-                logger.warning(str(f"{i} not a context member of {self}"))
-                continue
-            else:
-                self.context[i] = ctx[i]
-        self.save()
-
     def destroy(self):
         """
         Destroys self from memory and persistent storage
