@@ -305,6 +305,11 @@ class JsctlTest(TestCaseHelper, TestCase):
         self.assertTrue(r[4].startswith('  "tests": 3'))
         self.assertTrue(r[7].startswith('  "success": true'))
 
+    def test_jsctl_jac_disas_jir(self):
+        r = self.call("jac disas jaseci/jsctl/tests/teststest.jir")
+        self.assertIn("LOAD_CONST", r)
+        self.assertIn("LOAD_VAR", r)
+
     def test_jsctl_jac_run(self):
         r = self.call_cast("jac run jaseci/jsctl/tests/teststest.jac")
         self.assertEqual(r["report"], [{}, 4])
