@@ -3,6 +3,9 @@ from .common import CommonService, ProxyService, MetaProperties
 from .redis import RedisService
 from .task import TaskService
 from .mail import MailService
+from .kubernetes import KubernetesService
+from .prometheus import PromotheusService
+from .jsorc import JsOrcService
 from .meta import MetaService
 
 __all__ = [
@@ -13,5 +16,8 @@ __all__ = [
     "RedisService",
     "TaskService",
     "MailService",
+    "KubernetesService",
+    "PromotheusService",
+    "JsOrcService",
     "MetaService",
 ]
